$SPITSHELL > $DEBIAN_DIR/$PRODUCT.postinst <<!GROK!THIS!
#!/bin/sh
set -e

# dh_installdeb will replace this with shell code automatically
# generated by other debhelper scripts.

#DEBHELPER#

exit 0;

!GROK!THIS!
