$SPITSHELL > $APPLICATIONS_DIR/$PRODUCT.desktop <<!GROK!THIS!
[Desktop Entry]
Encoding=UTF-8
Name=EiffelStudio $RELEASE
Comment=EiffelStudio Integrated Development Environment ($VERSION)
Exec=/usr/bin/estudio$RELEASE_SUFFIX
Terminal=false
Type=Application
Icon=$PRODUCT
Categories=Development
!GROK!THIS!
