$SPITSHELL > $SVR_DIR/pkginfo <<!GROK!THIS!
PKG="$UNIX_NAME"
NAME="EiffelStudio $MAJOR_NUMBER.$MINOR_NUMBER"
ARCH="`uname -p`"
VERSION="$VERSION"
VENDOR="$ise_name"
CATEGORY="application"
DESC="$summary"
CLASSES="none"
DISPLAY=""
BASE_PREC=""
VISION2_PREC=""
!GROK!THIS!
