$SPITSHELL > $SVR_DIR/pkginfo <<!GROK!THIS!
PKG="$UNIX_NAME-doc"
NAME="EiffelStudio $MAJOR_NUMBER.$MINOR_NUMBER Documentation"
ARCH="i386,x86_64,sparc,sparc-64"
VERSION="$VERSION"
VENDOR="$ise_name"
CATEGORY="application"
DESC="$summary (Documentation)"
CLASSES="none"
!GROK!THIS!
